<?php

namespace Eform\Faq\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Eform\Faq\Forms\Faq as FaqForm;
use Eform\Faq\Http\Requests\FaqResourceRequest;
use Eform\Faq\Http\Resources\FaqResource;
use Eform\Faq\Http\Resources\FaqsCollection;
use Eform\Faq\Models\Faq;
use Eform\Faq\Actions\FaqAction;
use Eform\Faq\Actions\FaqActions;


/**
 * Resource controller class for faq.
 */
class FaqResourceController extends BaseController
{

    /**
     * Initialize faq resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = FaqForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('eform.faq.modules'), 'faq', guard_url('faq'));
            return $next($request);
        });
    }

    /**
     * Display a list of faq.
     *
     * @return Response
     */
    public function index(FaqResourceRequest $request)
    {
        $request = $request->all();
        $page = FaqActions::run('paginate', $request);

        $data = new FaqsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('faq::faq.names'))
            ->view('faq::faq.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display faq.
     *
     * @param Request $request
     * @param Model   $faq
     *
     * @return Response
     */
    public function show(FaqResourceRequest $request, Faq $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FaqResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('faq::faq.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('faq::faq.show')
            ->output();
    }

    /**
     * Show the form for creating a new faq.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FaqResourceRequest $request, Faq $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FaqResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('faq::faq.name'))
            ->view('faq::faq.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new faq.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FaqResourceRequest $request, Faq $model)
    {
        try {
            $request = $request->all();
            $model = FaqAction::run('store', $model, $request);
            $data = new FaqResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('faq::faq.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('faq/faq/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/faq/faq'))
                ->redirect();
        }

    }

    /**
     * Show faq for editing.
     *
     * @param Request $request
     * @param Model   $faq
     *
     * @return Response
     */
    public function edit(FaqResourceRequest $request, Faq $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FaqResource($model);
        // return view('faq::faq.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('faq::faq.name'))
            ->view('faq::faq.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the faq.
     *
     * @param Request $request
     * @param Model   $faq
     *
     * @return Response
     */
    public function update(FaqResourceRequest $request, Faq $model)
    {
        try {
            $request = $request->all();
            $model = FaqAction::run('update', $model, $request);
            $data = new FaqResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('faq::faq.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('faq/faq/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('faq/faq/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the faq.
     *
     * @param Model   $faq
     *
     * @return Response
     */
    public function destroy(FaqResourceRequest $request, Faq $model)
    {
        try {

            $request = $request->all();
            $model = FaqAction::run('destroy', $model, $request);
            $data = new FaqResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('faq::faq.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('faq/faq/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('faq/faq/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
